==> jc-1.4.0.tar.gz: soot/coffi/Instruction__5fNewarray.h <==
// class soot.coffi.Instruction_Newarray

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class b569d3cf8762c695 soot_coffi_Instruction
// @dep_class b745961e0cd183e5 soot_coffi_Instruction__5fNewarray

// header file dependencies
// @dep_header soot_coffi_Instruction

#include "soot/coffi/Instruction.h"

#ifndef _JC_soot_coffi_Instruction__5fNewarray_H_
#define _JC_soot_coffi_Instruction__5fNewarray_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_soot_coffi_Instruction__5fNewarray$sub_refs	_jc_soot_coffi_Instruction__5fNewarray$sub_refs;
typedef struct _jc_soot_coffi_Instruction__5fNewarray$sub_nonrefs	_jc_soot_coffi_Instruction__5fNewarray$sub_nonrefs;
typedef struct _jc_soot_coffi_Instruction__5fNewarray$refs	_jc_soot_coffi_Instruction__5fNewarray$refs;
typedef struct _jc_soot_coffi_Instruction__5fNewarray$nonrefs	_jc_soot_coffi_Instruction__5fNewarray$nonrefs;
typedef struct _jc_soot_coffi_Instruction__5fNewarray$object	_jc_soot_coffi_Instruction__5fNewarray$object;

typedef struct _jc_soot_coffi_Instruction__5fNewarray$fields_struct	_jc_soot_coffi_Instruction__5fNewarray$fields_struct;
typedef const struct _jc_soot_coffi_Instruction__5fNewarray$vmethods	_jc_soot_coffi_Instruction__5fNewarray$vmethods;
typedef const struct _jc_soot_coffi_Instruction__5fNewarray$vtable	_jc_soot_coffi_Instruction__5fNewarray$vtable;
typedef const struct _jc_soot_coffi_Instruction__5fNewarray$vtype	_jc_soot_coffi_Instruction__5fNewarray$vtype;

// Class fields structure
struct _jc_soot_coffi_Instruction__5fNewarray$fields_struct {
	jint	T__5fBOOLEAN;
	jint	T__5fBYTE;
	jint	T__5fCHAR;
	jint	T__5fDOUBLE;
	jint	T__5fFLOAT;
	jint	T__5fINT;
	jint	T__5fLONG;
	jint	T__5fSHORT;
};
extern _jc_soot_coffi_Instruction__5fNewarray$fields_struct _jc_soot_coffi_Instruction__5fNewarray$class_fields;

// Constructors
extern void _jc_soot_coffi_Instruction__5fNewarray$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_coffi_Instruction__5fNewarray$object *);

// Virtual methods
extern jint _jc_soot_coffi_Instruction__5fNewarray$method$compile$7850d747d603381b(_jc_env *, struct _jc_soot_coffi_Instruction__5fNewarray$object *, struct _jc_byte_array *, jint);
extern jint _jc_soot_coffi_Instruction__5fNewarray$method$nextOffset$f8d97a51150e6758(_jc_env *, struct _jc_soot_coffi_Instruction__5fNewarray$object *, jint);
extern jint _jc_soot_coffi_Instruction__5fNewarray$method$parse$107dd9a35b0eb485(_jc_env *, struct _jc_soot_coffi_Instruction__5fNewarray$object *, struct _jc_byte_array *, jint);
extern struct _jc_java_lang_String$object *_jc_soot_coffi_Instruction__5fNewarray$method$toString$9f9bf0b6fdab502b(_jc_env *, struct _jc_soot_coffi_Instruction__5fNewarray$object *, struct _jc_object_array *);

// Virtual method descriptors
extern _jc_method _jc_soot_coffi_Instruction__5fNewarray$method_info$compile$7850d747d603381b;
extern _jc_method _jc_soot_coffi_Instruction__5fNewarray$method_info$nextOffset$f8d97a51150e6758;
extern _jc_method _jc_soot_coffi_Instruction__5fNewarray$method_info$parse$107dd9a35b0eb485;
extern _jc_method _jc_soot_coffi_Instruction__5fNewarray$method_info$toString$9f9bf0b6fdab502b;

// Virtual methods structure
struct _jc_soot_coffi_Instruction__5fNewarray$vmethods {
	jint	(*compile$7850d747d603381b)(_jc_env *, struct _jc_soot_coffi_Instruction__5fNewarray$object *, struct _jc_byte_array *, jint);
	jint	(*nextOffset$f8d97a51150e6758)(_jc_env *, struct _jc_soot_coffi_Instruction__5fNewarray$object *, jint);
	jint	(*parse$107dd9a35b0eb485)(_jc_env *, struct _jc_soot_coffi_Instruction__5fNewarray$object *, struct _jc_byte_array *, jint);
	struct _jc_java_lang_String$object	*(*toString$9f9bf0b6fdab502b)(_jc_env *, struct _jc_soot_coffi_Instruction__5fNewarray$object *, struct _jc_object_array *);
};

// Vtable
struct _jc_soot_coffi_Instruction__5fNewarray$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_coffi_Instruction$vmethods	soot_coffi_Instruction;
	_jc_soot_coffi_Instruction__5fNewarray$vmethods	soot_coffi_Instruction__5fNewarray;
};

// Vtype
struct _jc_soot_coffi_Instruction__5fNewarray$vtype {
	_jc_type			type;
	_jc_soot_coffi_Instruction__5fNewarray$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5fNewarray$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_coffi_Instruction__5fNewarray$refs {
    _jc_soot_coffi_Instruction__5fNewarray$sub_refs	soot_coffi_Instruction__5fNewarray;
    _jc_soot_coffi_Instruction$sub_refs	soot_coffi_Instruction;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5fNewarray$sub_nonrefs {
	jbyte	atype;
};

// Non-reference instance fields (object)
struct _jc_soot_coffi_Instruction__5fNewarray$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_coffi_Instruction$sub_nonrefs	soot_coffi_Instruction;
    _jc_soot_coffi_Instruction__5fNewarray$sub_nonrefs	soot_coffi_Instruction__5fNewarray;
};

// Object instance structure
struct _jc_soot_coffi_Instruction__5fNewarray$object {
	_jc_soot_coffi_Instruction__5fNewarray$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_coffi_Instruction__5fNewarray$vtype	*vtype;
	_jc_soot_coffi_Instruction__5fNewarray$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_coffi_Instruction__5fNewarray$vtype _jc_soot_coffi_Instruction__5fNewarray$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_coffi_Instruction__5fNewarray, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_coffi_Instruction__5fNewarray$class_object;

#endif	/* _JC_soot_coffi_Instruction__5fNewarray_H_ */

==> jc-1.4.6.tar.gz: soot/coffi/Instruction__5fNewarray.h <==
// class soot.coffi.Instruction_Newarray

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class b569d3cf8762c695 soot_coffi_Instruction
// @dep_class b745961e0cd183e5 soot_coffi_Instruction__5fNewarray

// header file dependencies
// @dep_header soot_coffi_Instruction

#include "soot/coffi/Instruction.h"

#ifndef _JC_soot_coffi_Instruction__5fNewarray_H_
#define _JC_soot_coffi_Instruction__5fNewarray_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_soot_coffi_Instruction__5fNewarray$sub_refs	_jc_soot_coffi_Instruction__5fNewarray$sub_refs;
typedef struct _jc_soot_coffi_Instruction__5fNewarray$sub_nonrefs	_jc_soot_coffi_Instruction__5fNewarray$sub_nonrefs;
typedef struct _jc_soot_coffi_Instruction__5fNewarray$refs	_jc_soot_coffi_Instruction__5fNewarray$refs;
typedef struct _jc_soot_coffi_Instruction__5fNewarray$nonrefs	_jc_soot_coffi_Instruction__5fNewarray$nonrefs;
typedef struct _jc_soot_coffi_Instruction__5fNewarray$object	_jc_soot_coffi_Instruction__5fNewarray$object;

typedef struct _jc_soot_coffi_Instruction__5fNewarray$fields_struct	_jc_soot_coffi_Instruction__5fNewarray$fields_struct;
typedef const struct _jc_soot_coffi_Instruction__5fNewarray$vmethods	_jc_soot_coffi_Instruction__5fNewarray$vmethods;
typedef const struct _jc_soot_coffi_Instruction__5fNewarray$vtable	_jc_soot_coffi_Instruction__5fNewarray$vtable;
typedef const struct _jc_soot_coffi_Instruction__5fNewarray$vtype	_jc_soot_coffi_Instruction__5fNewarray$vtype;

// Class fields structure
struct _jc_soot_coffi_Instruction__5fNewarray$fields_struct {
	jint	T__5fBOOLEAN;
	jint	T__5fBYTE;
	jint	T__5fCHAR;
	jint	T__5fDOUBLE;
	jint	T__5fFLOAT;
	jint	T__5fINT;
	jint	T__5fLONG;
	jint	T__5fSHORT;
};
extern _jc_soot_coffi_Instruction__5fNewarray$fields_struct _jc_soot_coffi_Instruction__5fNewarray$class_fields;

// Constructors
extern void _jc_soot_coffi_Instruction__5fNewarray$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_coffi_Instruction__5fNewarray$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jint _jc_soot_coffi_Instruction__5fNewarray$method$compile$7850d747d603381b(_jc_env *, struct _jc_soot_coffi_Instruction__5fNewarray$object *, struct _jc_byte_array *, jint) _JC_JCNI_ATTR;
extern jint _jc_soot_coffi_Instruction__5fNewarray$method$nextOffset$f8d97a51150e6758(_jc_env *, struct _jc_soot_coffi_Instruction__5fNewarray$object *, jint) _JC_JCNI_ATTR;
extern jint _jc_soot_coffi_Instruction__5fNewarray$method$parse$107dd9a35b0eb485(_jc_env *, struct _jc_soot_coffi_Instruction__5fNewarray$object *, struct _jc_byte_array *, jint) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_coffi_Instruction__5fNewarray$method$toString$9f9bf0b6fdab502b(_jc_env *, struct _jc_soot_coffi_Instruction__5fNewarray$object *, struct _jc_object_array *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_coffi_Instruction__5fNewarray$method_info$compile$7850d747d603381b;
extern _jc_method _jc_soot_coffi_Instruction__5fNewarray$method_info$nextOffset$f8d97a51150e6758;
extern _jc_method _jc_soot_coffi_Instruction__5fNewarray$method_info$parse$107dd9a35b0eb485;
extern _jc_method _jc_soot_coffi_Instruction__5fNewarray$method_info$toString$9f9bf0b6fdab502b;

// Virtual methods structure
struct _jc_soot_coffi_Instruction__5fNewarray$vmethods {
	jint	(*compile$7850d747d603381b)(_jc_env *, struct _jc_soot_coffi_Instruction__5fNewarray$object *, struct _jc_byte_array *, jint) _JC_JCNI_ATTR;
	jint	(*nextOffset$f8d97a51150e6758)(_jc_env *, struct _jc_soot_coffi_Instruction__5fNewarray$object *, jint) _JC_JCNI_ATTR;
	jint	(*parse$107dd9a35b0eb485)(_jc_env *, struct _jc_soot_coffi_Instruction__5fNewarray$object *, struct _jc_byte_array *, jint) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$9f9bf0b6fdab502b)(_jc_env *, struct _jc_soot_coffi_Instruction__5fNewarray$object *, struct _jc_object_array *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_coffi_Instruction__5fNewarray$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_coffi_Instruction$vmethods	soot_coffi_Instruction;
	_jc_soot_coffi_Instruction__5fNewarray$vmethods	soot_coffi_Instruction__5fNewarray;
};

// Vtype
struct _jc_soot_coffi_Instruction__5fNewarray$vtype {
	_jc_type			type;
	_jc_soot_coffi_Instruction__5fNewarray$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5fNewarray$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_coffi_Instruction__5fNewarray$refs {
    _jc_soot_coffi_Instruction__5fNewarray$sub_refs	soot_coffi_Instruction__5fNewarray;
    _jc_soot_coffi_Instruction$sub_refs	soot_coffi_Instruction;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5fNewarray$sub_nonrefs {
	jbyte	atype;
};

// Non-reference instance fields (object)
struct _jc_soot_coffi_Instruction__5fNewarray$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_coffi_Instruction$sub_nonrefs	soot_coffi_Instruction;
    _jc_soot_coffi_Instruction__5fNewarray$sub_nonrefs	soot_coffi_Instruction__5fNewarray;
};

// Object instance structure
struct _jc_soot_coffi_Instruction__5fNewarray$object {
	_jc_soot_coffi_Instruction__5fNewarray$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_coffi_Instruction__5fNewarray$vtype	*vtype;
	_jc_soot_coffi_Instruction__5fNewarray$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_coffi_Instruction__5fNewarray$vtype _jc_soot_coffi_Instruction__5fNewarray$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_coffi_Instruction__5fNewarray, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_coffi_Instruction__5fNewarray$class_object;

#endif	/* _JC_soot_coffi_Instruction__5fNewarray_H_ */
